@@ -66,7 +66,8 @@ class KCal::CalendarResources::Private
         mStandardPolicy( new StandardDestinationPolicy( mManager ) ),
         mDestinationPolicy( mStandardPolicy ),
         mAskPolicy( new AskDestinationPolicy( mManager ) ),
-        mException( 0 )
+        mException( 0 ),
+        mPendingDeleteFromResourceMap( false )
     {}
     ~Private()
     {
@@ -88,6 +89,8 @@ class KCal::CalendarResources::Private
 
     ErrorFormat *mException;
 
+    bool mPendingDeleteFromResourceMap;
+
     template< class IncidenceList >
     void appendIncidences( IncidenceList &result, const IncidenceList &extra,
                            ResourceCalendar * );
@@ -154,6 +157,22 @@ CalendarResourceManager *CalendarResources::DestinationPolicy::resourceManager()
   return d->mManager;
 }
 
+bool CalendarResources::DestinationPolicy::hasCalendarResources()
+{
+  CalendarResourceManager::ActiveIterator it;
+  for ( it = resourceManager()->activeBegin();
+        it != resourceManager()->activeEnd(); ++it ) {
+    if ( !(*it)->readOnly() ) {
+      if ( resourceManager()->standardResource() == *it ) {
+        return true;
+      } else {
+        return true;
+      }
+    }
+  }
+  return false;
+}
+
 CalendarResources::StandardDestinationPolicy::StandardDestinationPolicy(
   CalendarResourceManager *manager, QWidget *parent )
   : DestinationPolicy( manager, parent ),
@@ -212,7 +231,6 @@ CalendarResources::CalendarResources( const KDateTime::Spec &timeSpec,
   : Calendar( timeSpec ),
     d( new KCal::CalendarResources::Private( family ) )
 {
-  mPendingDeleteFromResourceMap = false;
   d->mManager->addObserver( this );
 }
 
@@ -221,7 +239,6 @@ CalendarResources::CalendarResources( const QString &timeZoneId,
   : Calendar( timeZoneId ),
     d( new KCal::CalendarResources::Private( family ) )
 {
-  mPendingDeleteFromResourceMap = false;
   d->mManager->addObserver( this );
 }
 
@@ -400,6 +417,11 @@ bool CalendarResources::addIncidence( Incidence *incidence,
   return false;
 }
 
+bool CalendarResources::hasCalendarResources()
+{
+   return d->mDestinationPolicy->hasCalendarResources();
+}
+
 bool CalendarResources::addIncidence( Incidence *incidence )
 {
   clearException();
@@ -442,7 +464,7 @@ bool CalendarResources::deleteEvent( Event *event )
   if ( d->mResourceMap.find( event ) != d->mResourceMap.end() ) {
     status = d->mResourceMap[event]->deleteEvent( event );
     if ( status ) {
-      mPendingDeleteFromResourceMap = true;
+      d->mPendingDeleteFromResourceMap = true;
     }
   } else {
     status = false;
@@ -498,7 +520,7 @@ bool CalendarResources::deleteTodo( Todo *todo )
   if ( d->mResourceMap.find( todo ) != d->mResourceMap.end() ) {
     status = d->mResourceMap[todo]->deleteTodo( todo );
     if ( status ) {
-      mPendingDeleteFromResourceMap = true;
+      d->mPendingDeleteFromResourceMap = true;
     }
   } else {
     CalendarResourceManager::ActiveIterator it;
@@ -584,7 +606,7 @@ Alarm::List CalendarResources::alarms( const KDateTime &from,
 /****************************** PROTECTED METHODS ****************************/
 
 Event::List CalendarResources::rawEventsForDate( const QDate &date,
-                                                 const KDateTime::Spec &timespec,
+                                                 const KDateTime::Spec &timeSpec,
                                                  EventSortField sortField,
                                                  SortDirection sortDirection )
 {
@@ -592,19 +614,19 @@ Event::List CalendarResources::rawEventsForDate( const QDate &date,
   CalendarResourceManager::ActiveIterator it;
   for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
     d->appendIncidences<Event::List>( result,
-                                      (*it)->rawEventsForDate( date, timespec ), *it );
+                                      (*it)->rawEventsForDate( date, timeSpec ), *it );
   }
   return sortEvents( &result, sortField, sortDirection );
 }
 
 Event::List CalendarResources::rawEvents( const QDate &start, const QDate &end,
-                                          const KDateTime::Spec &timespec, bool inclusive )
+                                          const KDateTime::Spec &timeSpec, bool inclusive )
 {
   Event::List result;
   CalendarResourceManager::ActiveIterator it;
   for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
     d->appendIncidences<Event::List>( result,
-                                      (*it)->rawEvents( start, end, timespec, inclusive ), *it );
+                                      (*it)->rawEvents( start, end, timeSpec, inclusive ), *it );
   }
   return result;
 }
@@ -644,7 +666,7 @@ bool CalendarResources::deleteJournal( Journal *journal )
   if ( d->mResourceMap.find( journal ) != d->mResourceMap.end() ) {
     status = d->mResourceMap[journal]->deleteJournal( journal );
     if ( status ) {
-      mPendingDeleteFromResourceMap = true;
+      d->mPendingDeleteFromResourceMap = true;
     }
   } else {
     CalendarResourceManager::ActiveIterator it;
@@ -845,7 +867,7 @@ bool CalendarResources::beginChange( Incidence *incidence )
     }
     d->mResourceMap[ incidence ] = r;
   }
-  mPendingDeleteFromResourceMap = false;
+  d->mPendingDeleteFromResourceMap = false;
 
   int count = incrementChangeCount( r );
   if ( count == 1 ) {
@@ -871,9 +893,9 @@ bool CalendarResources::endChange( Incidence *incidence )
 
   int count = decrementChangeCount( r );
 
-  if ( mPendingDeleteFromResourceMap ) {
+  if ( d->mPendingDeleteFromResourceMap ) {
     d->mResourceMap.remove( incidence );
-    mPendingDeleteFromResourceMap = false;
+    d->mPendingDeleteFromResourceMap = false;
   }
 
   if ( count == 0 ) {
