@@ -39,6 +39,10 @@
 
 #include <QtCore/QList>
 
+namespace boost {
+  template <typename T> class shared_ptr;
+}
+
 namespace KCal {
 
 /**
@@ -50,11 +54,11 @@ namespace KCal {
   so they are not in IncidenceBase. The hierarchy is:
 
   IncidenceBase
-  - FreeBusy
-  - Incidence
-  - Event
-  - Todo
-  - Journal
+  + FreeBusy
+  + Incidence
+    + Event
+    + Todo
+    + Journal
 
   So IncidenceBase contains all properties that are common to all classes,
   and Incidence contains all additional properties that are common to
@@ -165,6 +169,11 @@ class KCAL_EXPORT Incidence //krazy:exclude=dpointer since nested class template
     */
     typedef ListBase<Incidence> List;
 
+    /**
+      A shared pointer to an Incidence.
+    */
+    typedef boost::shared_ptr<Incidence> Ptr;
+
     /**
       Constructs an empty incidence.*
     */
@@ -307,7 +316,7 @@ class KCAL_EXPORT Incidence //krazy:exclude=dpointer since nested class template
     void setSummary( const QString &summary, bool isRich );
 
     /**
-      Sets the incidence summary and tries to guess if the summary is richtext..
+      Sets the incidence summary and tries to guess if the summary is richtext.
 
       @param summary is the incidence summary string.
       @see summary().
@@ -350,7 +359,6 @@ class KCAL_EXPORT Incidence //krazy:exclude=dpointer since nested class template
       richtext. Do _not_ use with journals.
 
       @param location is the incidence location string.
-      @param isRich if true indicates the location string contains richtext.
       @see location().
       @since 4.1
     */
@@ -700,6 +708,53 @@ class KCAL_EXPORT Incidence //krazy:exclude=dpointer since nested class template
     */
     int priority() const;
 
+    /**
+      Returns true if the incidence has geo data, otherwise return false.
+      @see setHasGeo(), setGeoLatitude(float), setGeoLongitude(float).
+      @since 4.3
+    */
+    bool hasGeo() const;
+
+    /**
+      Sets if the incidence has geo data.
+      @param hasGeo true if incidence has geo data, otherwise false
+      @see hasGeo(), geoLatitude(), geoLongitude().
+      @since 4.3
+    */
+    void setHasGeo( bool hasGeo );
+
+    /**
+      Set the incidences geoLatitude.
+      @param geolatitude is the incidence geolatitude to set
+      @see geoLatitude().
+      @since 4.3
+    */
+    void setGeoLatitude( float geolatitude );
+
+    /**
+      Returns the incidence geoLatidude.
+      @return incidences geolatitude value
+      @see setGeoLatitude().
+      @since 4.3
+    */
+    float &geoLatitude() const;
+
+    /**
+      Set the incidencesgeoLongitude.
+      @param geolongitude is the incidence geolongitude to set
+      @see geoLongitude().
+      @since 4.3
+    */
+    void setGeoLongitude( float geolongitude );
+
+    /**
+      Returns the incidence geoLongitude.
+      @return incidences geolongitude value
+      @see setGeoLongitude().
+      @since 4.3
+    */
+    float &geoLongitude() const;
+
 // %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 // %%%%%  Alarm-related methods
 // %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -777,15 +832,30 @@ class KCAL_EXPORT Incidence //krazy:exclude=dpointer since nested class template
 
     /**
       Assignment operator.
+
+      @warning Not polymorphic. Use AssignmentVisitor for correct
+      assignment of an instance of type IncidenceBase to another
+      instance of type Incidence.
+
+      @param other is the Incidence to assign.
+
+      @see AssignmentVisitor
      */
-    Incidence &operator=( const Incidence &other );
+    Incidence &operator=( const Incidence &other ); // KDE5: make protected to
+                                                    // prevent accidental usage
 
     /**
-      Compare this with @p incidence for equality.
+      Compares this with Incidence @p ib for equality.
 
-      @param incidence is the incidence to compare.
+      @warning Not polymorphic. Use ComparisonVisitor for correct
+      comparison of two instances of type Incidence.
+
+      @param incidence is the Incidence to compare.
+
+      @see ComparisonVisitor
     */
-    bool operator==( const Incidence &incidence ) const;
+    bool operator==( const Incidence &incidence ) const; // KDE5: make protected to
+                                                         // prevent accidental usage
 
   protected:
     /**
