@@ -70,11 +70,9 @@ imap://server/folder/
 #include <sys/wait.h>
 #include <errno.h>
 
-#ifdef HAVE_LIBSASL2
 extern "C" {
 #include <sasl/sasl.h>
 }
-#endif
 
 #include <qbuffer.h>
 #include <qdatetime.h>
@@ -119,10 +117,8 @@ kdemain (int argc, char **argv)
     ::exit (-1);
   }
 
-#ifdef HAVE_LIBSASL2
   if (!initSASL())
     ::exit(-1);
-#endif
 
   //set debug handler
 
@@ -136,9 +132,7 @@ kdemain (int argc, char **argv)
   slave->dispatchLoop ();
   delete slave;
 
-#ifdef HAVE_LIBSASL2
   sasl_done();
-#endif
 
   return 0;
 }
@@ -206,7 +200,7 @@ IMAP4Protocol::get (const KUrl & _url)
 
   if (aSequence == "0:0" && getState() == ISTATE_SELECT)
   {
-    imapCommand *cmd = doCommand (imapCommand::clientNoop());
+    CommandPtr cmd = doCommand (imapCommand::clientNoop());
     completeQueue.removeAll(cmd);
   }
 
@@ -216,7 +210,7 @@ IMAP4Protocol::get (const KUrl & _url)
   }
 
   mProcessedSize = 0;
-  imapCommand *cmd = NULL;
+  CommandPtr cmd;
   if (!assureBox (aBox, true)) return;
 
 #ifdef USE_VALIDITY
@@ -428,7 +422,7 @@ IMAP4Protocol::listDir (const KUrl & _url)
   if (myType == ITYPE_DIR || myType == ITYPE_DIR_AND_BOX)
   {
     QString listStr = myBox;
-    imapCommand *cmd;
+    CommandPtr cmd;
 
     if (!listStr.isEmpty () && !listStr.endsWith(myDelimiter) &&
         mySection != "FOLDERONLY")
@@ -513,7 +507,7 @@ IMAP4Protocol::listDir (const KUrl & _url)
       query = query.right (query.length () - 1);
       if (!query.isEmpty())
       {
-        imapCommand *cmd = NULL;
+        CommandPtr cmd;
 
         if (!assureBox (myBox, true)) return;
 
@@ -598,7 +592,7 @@ IMAP4Protocol::listDir (const KUrl & _url)
         if (mySection.isEmpty()) mySection = "UID RFC822.SIZE ENVELOPE";
 
         bool withFlags = mySection.toUpper().contains("FLAGS") ;
-        imapCommand *fetch =
+        CommandPtr fetch =
           sendCommand (imapCommand::
                        clientFetch (mySequence, mySection));
         imapCache *cache;
@@ -796,7 +790,7 @@ IMAP4Protocol::put (const KUrl & _url, int, KIO::JobFlags)
   {
     if (aBox[aBox.length () - 1] == '/')
       aBox = aBox.right (aBox.length () - 1);
-    imapCommand *cmd = doCommand (imapCommand::clientCreate (aBox));
+    CommandPtr cmd = doCommand (imapCommand::clientCreate (aBox));
 
     if (cmd->result () != "OK") {
       error (ERR_COULD_NOT_WRITE, _url.prettyUrl());
@@ -833,7 +827,7 @@ IMAP4Protocol::put (const KUrl & _url, int, KIO::JobFlags)
       return;
     }
 
-    imapCommand *cmd =
+    CommandPtr cmd =
       sendCommand (imapCommand::clientAppend (aBox, aSection, length));
     while (!parseLoop ()) {}
 
@@ -926,7 +920,7 @@ IMAP4Protocol::mkdir (const KUrl & _url, int)
   QString aBox, aSequence, aLType, aSection, aValidity, aDelimiter, aInfo;
   parseURL(_url, aBox, aSection, aLType, aSequence, aValidity, aDelimiter, aInfo);
   kDebug(7116) <<"IMAP4::mkdir - create" << aBox;
-  imapCommand *cmd = doCommand (imapCommand::clientCreate(aBox));
+  CommandPtr cmd = doCommand (imapCommand::clientCreate(aBox));
 
   if (cmd->result () != "OK")
   {
@@ -1018,7 +1012,7 @@ IMAP4Protocol::copy (const KUrl & src, const KUrl & dest, int, KIO::JobFlags fla
         if (dType != ITYPE_BOX && dType != ITYPE_DIR_AND_BOX)
         {
           // ok then we'll create a mailbox
-          imapCommand *cmd = doCommand (imapCommand::clientCreate (topDir));
+          CommandPtr cmd = doCommand (imapCommand::clientCreate (topDir));
 
           // on success we'll use it, else we'll just try to create the given dir
           if (cmd->result () == "OK")
@@ -1049,7 +1043,7 @@ IMAP4Protocol::copy (const KUrl & src, const KUrl & dest, int, KIO::JobFlags fla
     kDebug(7116) <<"IMAP4::copy -" << sBox <<" ->" << dBox;
 
     //issue copy command
-    imapCommand *cmd =
+    CommandPtr cmd =
       doCommand (imapCommand::clientCopy (dBox, sSequence));
     if (cmd->result () != "OK")
     {
@@ -1096,7 +1090,7 @@ IMAP4Protocol::del (const KUrl & _url, bool isFile)
       if (aSequence == "*")
       {
         if (!assureBox (aBox, false)) return;
-        imapCommand *cmd = doCommand (imapCommand::clientExpunge ());
+        CommandPtr cmd = doCommand (imapCommand::clientExpunge ());
         if (cmd->result () != "OK") {
           error (ERR_CANNOT_DELETE, _url.prettyUrl());
           completeQueue.removeAll (cmd);
@@ -1108,7 +1102,7 @@ IMAP4Protocol::del (const KUrl & _url, bool isFile)
       {
         // if open for read/write
         if (!assureBox (aBox, false)) return;
-        imapCommand *cmd =
+        CommandPtr cmd =
           doCommand (imapCommand::
                      clientStore (aSequence, "+FLAGS.SILENT", "\\DELETED"));
         if (cmd->result () != "OK") {
@@ -1123,12 +1117,12 @@ IMAP4Protocol::del (const KUrl & _url, bool isFile)
     {
       if (getCurrentBox() == aBox)
       {
-        imapCommand *cmd = doCommand(imapCommand::clientClose());
+        CommandPtr cmd = doCommand(imapCommand::clientClose());
         completeQueue.removeAll(cmd);
         setState(ISTATE_LOGIN);
       }
       // We unsubscribe, otherwise we get ghost folders on UW-IMAP
-      imapCommand *cmd = doCommand(imapCommand::clientUnsubscribe(aBox));
+      CommandPtr cmd = doCommand(imapCommand::clientUnsubscribe(aBox));
       completeQueue.removeAll(cmd);
       cmd = doCommand(imapCommand::clientDelete (aBox));
       // If this doesn't work, we try to empty the mailbox first
@@ -1139,21 +1133,21 @@ IMAP4Protocol::del (const KUrl & _url, bool isFile)
         bool stillOk = true;
         if (stillOk)
         {
-          imapCommand *cmd = doCommand(
+          CommandPtr cmd = doCommand(
             imapCommand::clientStore("1:*", "+FLAGS.SILENT", "\\DELETED"));
           if (cmd->result () != "OK") stillOk = false;
           completeQueue.removeAll(cmd);
         }
         if (stillOk)
         {
-          imapCommand *cmd = doCommand(imapCommand::clientClose());
+          CommandPtr cmd = doCommand(imapCommand::clientClose());
           if (cmd->result () != "OK") stillOk = false;
           completeQueue.removeAll(cmd);
           setState(ISTATE_LOGIN);
         }
         if (stillOk)
         {
-          imapCommand *cmd = doCommand (imapCommand::clientDelete(aBox));
+          CommandPtr cmd = doCommand (imapCommand::clientDelete(aBox));
           if (cmd->result () != "OK") stillOk = false;
           completeQueue.removeAll(cmd);
         }
@@ -1170,7 +1164,7 @@ IMAP4Protocol::del (const KUrl & _url, bool isFile)
 
   case ITYPE_DIR:
     {
-      imapCommand *cmd = doCommand (imapCommand::clientDelete (aBox));
+      CommandPtr cmd = doCommand (imapCommand::clientDelete (aBox));
       if (cmd->result () != "OK") {
         error (ERR_COULD_NOT_RMDIR, _url.prettyUrl());
         completeQueue.removeAll (cmd);
@@ -1184,7 +1178,7 @@ IMAP4Protocol::del (const KUrl & _url, bool isFile)
     {
       // if open for read/write
       if (!assureBox (aBox, false)) return;
-      imapCommand *cmd =
+      CommandPtr cmd =
         doCommand (imapCommand::
                    clientStore (aSequence, "+FLAGS.SILENT", "\\DELETED"));
       if (cmd->result () != "OK") {
@@ -1251,7 +1245,7 @@ IMAP4Protocol::special (const QByteArray & aData)
   case 'N':
   {
     // NOOP
-    imapCommand *cmd = doCommand(imapCommand::clientNoop());
+    CommandPtr cmd = doCommand(imapCommand::clientNoop());
     if (cmd->result () != "OK")
     {
       kDebug(7116) <<"NOOP did not succeed - connection broken";
@@ -1260,7 +1254,6 @@ IMAP4Protocol::special (const QByteArray & aData)
       return;
     }
     completeQueue.removeAll (cmd);
-    delete cmd;
     finished();
     break;
   }
@@ -1279,7 +1272,7 @@ IMAP4Protocol::special (const QByteArray & aData)
     stream >> _url;
     QString aBox, aSequence, aLType, aSection, aValidity, aDelimiter, aInfo;
     parseURL (_url, aBox, aSection, aLType, aSequence, aValidity, aDelimiter, aInfo);
-    imapCommand *cmd = doCommand(imapCommand::clientUnsubscribe(aBox));
+    CommandPtr cmd = doCommand(imapCommand::clientUnsubscribe(aBox));
     if (cmd->result () != "OK")
     {
       completeQueue.removeAll (cmd);
@@ -1300,7 +1293,7 @@ IMAP4Protocol::special (const QByteArray & aData)
     stream >> _url;
     QString aBox, aSequence, aLType, aSection, aValidity, aDelimiter, aInfo;
     parseURL (_url, aBox, aSection, aLType, aSequence, aValidity, aDelimiter, aInfo);
-    imapCommand *cmd = doCommand(imapCommand::clientSubscribe(aBox));
+    CommandPtr cmd = doCommand(imapCommand::clientSubscribe(aBox));
     if (cmd->result () != "OK")
     {
       completeQueue.removeAll (cmd);
@@ -1322,7 +1315,7 @@ IMAP4Protocol::special (const QByteArray & aData)
     if ( hasCapability( "ACL" ) ) {
       specialACLCommand( cmd, stream );
     } else {
-      error( ERR_UNSUPPORTED_ACTION, "ACL" );
+      error( ERR_UNSUPPORTED_ACTION, QString::fromLatin1("ACL") );
     }
     break;
   }
@@ -1334,7 +1327,7 @@ IMAP4Protocol::special (const QByteArray & aData)
     if ( hasCapability( "ANNOTATEMORE" ) ) {
       specialAnnotateMoreCommand( cmd, stream );
     } else {
-      error( ERR_UNSUPPORTED_ACTION, "ANNOTATEMORE" );
+      error( ERR_UNSUPPORTED_ACTION, QString::fromLatin1("ANNOTATEMORE") );
     }
     break;
   }
@@ -1346,7 +1339,7 @@ IMAP4Protocol::special (const QByteArray & aData)
     if ( hasCapability( "QUOTA" ) ) {
       specialQuotaCommand( cmd, stream );
     } else {
-      error( ERR_UNSUPPORTED_ACTION, "QUOTA" );
+      error( ERR_UNSUPPORTED_ACTION, QString::fromLatin1("QUOTA") );
     }
     break;
   }
@@ -1368,8 +1361,8 @@ IMAP4Protocol::special (const QByteArray & aData)
       knownFlags += " KMAILFORWARDED KMAILTODO KMAILWATCHED KMAILIGNORED $FORWARDED $TODO $WATCHED $IGNORED";
     }
 
-    imapCommand *cmd = doCommand (imapCommand::
-                                  clientStore (aSequence, "-FLAGS.SILENT", knownFlags));
+    CommandPtr cmd = doCommand (imapCommand::
+                                clientStore (aSequence, "-FLAGS.SILENT", knownFlags));
     if (cmd->result () != "OK")
     {
       completeQueue.removeAll (cmd);
@@ -1407,7 +1400,7 @@ IMAP4Protocol::special (const QByteArray & aData)
     if ( !assureBox(aBox, true) ) // read-only because changing SEEN should be possible even then
       return;
 
-    imapCommand *cmd;
+    CommandPtr cmd;
     if ( seen )
       cmd = doCommand( imapCommand::clientStore( aSequence, "+FLAGS.SILENT", "\\SEEN" ) );
     else
@@ -1459,7 +1452,7 @@ IMAP4Protocol::specialACLCommand( int command, QDataStream& stream )
     QString user, acl;
     stream >> user >> acl;
     kDebug(7116) <<"SETACL" << aBox << user << acl;
-    imapCommand *cmd = doCommand(imapCommand::clientSetACL(aBox, user, acl));
+    CommandPtr cmd = doCommand(imapCommand::clientSetACL(aBox, user, acl));
     if (cmd->result () != "OK")
     {
       error(ERR_SLAVE_DEFINED, i18n("Setting the Access Control List on folder %1 "
@@ -1478,7 +1471,7 @@ IMAP4Protocol::specialACLCommand( int command, QDataStream& stream )
     QString user;
     stream >> user;
     kDebug(7116) <<"DELETEACL" << aBox << user;
-    imapCommand *cmd = doCommand(imapCommand::clientDeleteACL(aBox, user));
+    CommandPtr cmd = doCommand(imapCommand::clientDeleteACL(aBox, user));
     if (cmd->result () != "OK")
     {
       error(ERR_SLAVE_DEFINED, i18n("Deleting the Access Control List on folder %1 "
@@ -1495,7 +1488,7 @@ IMAP4Protocol::specialACLCommand( int command, QDataStream& stream )
   case 'G': // GETACL
   {
     kDebug(7116) <<"GETACL" << aBox;
-    imapCommand *cmd = doCommand(imapCommand::clientGetACL(aBox));
+    CommandPtr cmd = doCommand(imapCommand::clientGetACL(aBox));
     if (cmd->result () != "OK")
     {
       error(ERR_SLAVE_DEFINED, i18n("Retrieving the Access Control List on folder %1 "
@@ -1522,7 +1515,7 @@ IMAP4Protocol::specialACLCommand( int command, QDataStream& stream )
   case 'M': // MYRIGHTS
   {
     kDebug(7116) <<"MYRIGHTS" << aBox;
-    imapCommand *cmd = doCommand(imapCommand::clientMyRights(aBox));
+    CommandPtr cmd = doCommand(imapCommand::clientMyRights(aBox));
     if (cmd->result () != "OK")
     {
       error(ERR_SLAVE_DEFINED, i18n("Retrieving the Access Control List on folder %1 "
@@ -1554,9 +1547,9 @@ IMAP4Protocol::specialSearchCommand( QDataStream& stream )
   stream >> _url;
   QString aBox, aSequence, aLType, aSection, aValidity, aDelimiter, aInfo;
   parseURL (_url, aBox, aSection, aLType, aSequence, aValidity, aDelimiter, aInfo);
-  if (!assureBox(aBox, false)) return;
+  if (!assureBox(aBox, true)) return;
 
-  imapCommand *cmd = doCommand (imapCommand::clientSearch( aSection ));
+  CommandPtr cmd = doCommand (imapCommand::clientSearch( aSection ));
   if (cmd->result () != "OK")
   {
     error(ERR_SLAVE_DEFINED, i18n("Searching of folder %1 "
@@ -1590,7 +1583,7 @@ IMAP4Protocol::specialCustomCommand( QDataStream& stream )
    */
   if ( type == 'N' ) {
     kDebug(7116) << "IMAP4Protocol::specialCustomCommand: normal mode" << endl;
-    imapCommand *cmd = doCommand (imapCommand::clientCustom( command, arguments ));
+    CommandPtr cmd = doCommand (imapCommand::clientCustom( command, arguments ));
     if (cmd->result () != "OK")
     {
       error( ERR_SLAVE_DEFINED,
@@ -1613,7 +1606,7 @@ IMAP4Protocol::specialCustomCommand( QDataStream& stream )
    */
   if ( type == 'E' ) {
     kDebug(7116) << "IMAP4Protocol::specialCustomCommand: extended mode" << endl;
-    imapCommand *cmd = sendCommand (imapCommand::clientCustom( command, QString() ));
+    CommandPtr cmd = sendCommand (imapCommand::clientCustom( command, QString() ));
     while ( !parseLoop () ) {};
 
     // see if server is waiting
@@ -1671,7 +1664,7 @@ IMAP4Protocol::specialAnnotateMoreCommand( int command, QDataStream& stream )
     QMap<QString, QString> attributes;
     stream >> entry >> attributes;
     kDebug(7116) <<"SETANNOTATION" << aBox << entry << attributes.count() <<" attributes";
-    imapCommand *cmd = doCommand(imapCommand::clientSetAnnotation(aBox, entry, attributes));
+    CommandPtr cmd = doCommand(imapCommand::clientSetAnnotation(aBox, entry, attributes));
     if (cmd->result () != "OK")
     {
       error(ERR_SLAVE_DEFINED, i18n("Setting the annotation %1 on folder %2 "
@@ -1695,7 +1688,7 @@ IMAP4Protocol::specialAnnotateMoreCommand( int command, QDataStream& stream )
     QStringList attributeNames;
     stream >> entry >> attributeNames;
     kDebug(7116) <<"GETANNOTATION" << aBox << entry << attributeNames;
-    imapCommand *cmd = doCommand(imapCommand::clientGetAnnotation(aBox, entry, attributeNames));
+    CommandPtr cmd = doCommand(imapCommand::clientGetAnnotation(aBox, entry, attributeNames));
     if (cmd->result () != "OK")
     {
       error(ERR_SLAVE_DEFINED, i18n("Retrieving the annotation %1 on folder %2 "
@@ -1732,7 +1725,7 @@ IMAP4Protocol::specialQuotaCommand( int command, QDataStream& stream )
     case 'R': // GETQUOTAROOT
       {
         kDebug(7116) <<"QUOTAROOT" << aBox;
-        imapCommand *cmd = doCommand(imapCommand::clientGetQuotaroot( aBox ) );
+        CommandPtr cmd = doCommand(imapCommand::clientGetQuotaroot( aBox ) );
         if (cmd->result () != "OK")
         {
           error(ERR_SLAVE_DEFINED, i18n("Retrieving the quota root information on folder %1 "
@@ -1786,7 +1779,7 @@ IMAP4Protocol::rename (const KUrl & src, const KUrl & dest, KIO::JobFlags flags)
         {
           kDebug(7116) <<"IMAP4::rename - close" << getCurrentBox();
           // mailbox can only be renamed if it is closed
-          imapCommand *cmd = doCommand (imapCommand::clientClose());
+          CommandPtr cmd = doCommand (imapCommand::clientClose());
           bool ok = cmd->result() == "OK";
           completeQueue.removeAll(cmd);
           if (!ok)
@@ -1796,7 +1789,7 @@ IMAP4Protocol::rename (const KUrl & src, const KUrl & dest, KIO::JobFlags flags)
           }
           setState(ISTATE_LOGIN);
         }
-        imapCommand *cmd = doCommand (imapCommand::clientRename (sBox, dBox));
+        CommandPtr cmd = doCommand (imapCommand::clientRename (sBox, dBox));
         if (cmd->result () != "OK") {
           error (ERR_CANNOT_RENAME, cmd->result ());
           completeQueue.removeAll (cmd);
@@ -1854,7 +1847,7 @@ IMAP4Protocol::stat (const KUrl & _url)
   {
     if (getState() == ISTATE_SELECT && aBox == getCurrentBox())
     {
-      imapCommand *cmd = doCommand (imapCommand::clientClose());
+      CommandPtr cmd = doCommand (imapCommand::clientClose());
       bool ok = cmd->result() == "OK";
       completeQueue.removeAll(cmd);
       if (!ok)
@@ -1870,7 +1863,7 @@ IMAP4Protocol::stat (const KUrl & _url)
       ok = true;
     else
     {
-      imapCommand *cmd = doCommand(imapCommand::clientStatus(aBox, aSection));
+      CommandPtr cmd = doCommand(imapCommand::clientStatus(aBox, aSection));
       ok = cmd->result() == "OK";
       cmdInfo = cmd->resultInfo();
       completeQueue.removeAll(cmd);
@@ -1878,7 +1871,7 @@ IMAP4Protocol::stat (const KUrl & _url)
     if (!ok)
     {
       bool found = false;
-      imapCommand *cmd = doCommand (imapCommand::clientList ("", aBox));
+      CommandPtr cmd = doCommand (imapCommand::clientList ("", aBox));
       if (cmd->result () == "OK")
       {
         for (QList< imapList >::Iterator it = listResponses.begin ();
@@ -1913,7 +1906,7 @@ IMAP4Protocol::stat (const KUrl & _url)
       // do a status lookup on the box
       // only do this if the box is not selected
       // the server might change the validity for new select/examine
-      imapCommand *cmd =
+      CommandPtr cmd =
         doCommand (imapCommand::clientStatus (aBox, "UIDVALIDITY"));
       completeQueue.removeAll (cmd);
       validity = getStatus ().uidValidity ();
@@ -1991,12 +1984,12 @@ void IMAP4Protocol::closeConnection()
   if (getState() == ISTATE_NO) return;
   if (getState() == ISTATE_SELECT && metaData("expunge") == "auto")
   {
-    imapCommand *cmd = doCommand (imapCommand::clientExpunge());
+    CommandPtr cmd = doCommand (imapCommand::clientExpunge());
     completeQueue.removeAll (cmd);
   }
   if (getState() != ISTATE_CONNECT)
   {
-    imapCommand *cmd = doCommand (imapCommand::clientLogout());
+    CommandPtr cmd = doCommand (imapCommand::clientLogout());
     completeQueue.removeAll (cmd);
   }
   disconnectFromHost();
@@ -2027,14 +2020,14 @@ bool IMAP4Protocol::makeLogin ()
     myTLS  = metaData("tls");
     kDebug(7116) <<"myAuth:" << myAuth;
 
-    imapCommand *cmd;
+    CommandPtr cmd;
 
     unhandled.clear ();
     if (!alreadyConnected) while (!parseLoop ()) {}   //get greeting
     QString greeting;
     if (!unhandled.isEmpty()) greeting = unhandled.first().trimmed();
     unhandled.clear ();       //get rid of it
-    cmd = doCommand (new imapCommand ("CAPABILITY", ""));
+    cmd = doCommand (CommandPtr(new imapCommand ("CAPABILITY", "")));
 
     kDebug(7116) <<"IMAP4: setHost: capability";
     for (QStringList::const_iterator it = imapCapabilities.constBegin ();
@@ -2043,7 +2036,6 @@ bool IMAP4Protocol::makeLogin ()
       kDebug(7116) <<"'" << (*it) <<"'";
     }
     completeQueue.removeAll (cmd);
-    delete cmd;
 
     if (!hasCapability("IMAP4") && !hasCapability("IMAP4rev1"))
     {
@@ -2066,14 +2058,14 @@ bool IMAP4Protocol::makeLogin ()
     if ((myTLS == "on" /*###|| ( canUseTLS() && myTLS != "off")*/) &&
         hasCapability(QString("STARTTLS")))
     {
-      imapCommand *cmd = doCommand (imapCommand::clientStartTLS());
+      CommandPtr cmd = doCommand (imapCommand::clientStartTLS());
       if (cmd->result () == "OK")
       {
         completeQueue.removeAll(cmd);
         if (startSsl())
         {
           kDebug(7116) <<"TLS mode has been enabled.";
-          imapCommand *cmd2 = doCommand (new imapCommand ("CAPABILITY", ""));
+          CommandPtr cmd2 = doCommand (CommandPtr(new imapCommand ("CAPABILITY", "")));
           for (QStringList::const_iterator it = imapCapabilities.constBegin ();
                                      it != imapCapabilities.constEnd (); ++it)
           {
@@ -2084,11 +2076,9 @@ bool IMAP4Protocol::makeLogin ()
           kWarning(7116) <<"TLS mode setup has failed.  Aborting.";
           error (ERR_COULD_NOT_LOGIN, i18n("Starting TLS failed."));
           closeConnection();
-          delete cmd;
           return false;
         }
       } else completeQueue.removeAll(cmd);
-      delete cmd;
     }
 
     if (!myAuth.isEmpty () && myAuth != "*"
@@ -2104,6 +2094,18 @@ bool IMAP4Protocol::makeLogin ()
       removeCapability( "ANNOTATEMORE" );
     }
 
+    // starting from Cyrus IMAP 2.3.9, shared seen flags are available
+    QRegExp regExp( "Cyrus\\sIMAP[4]{0,1}\\sv(\\d+)\\.(\\d+)\\.(\\d+)", Qt::CaseInsensitive );
+    if ( regExp.indexIn( greeting ) >= 0 ) {
+      const int major = regExp.cap( 1 ).toInt();
+      const int minor = regExp.cap( 2 ).toInt();
+      const int patch = regExp.cap( 3 ).toInt();
+      if ( major > 2 || (major == 2 && (minor > 3 || (minor == 3 && patch > 9))) ) {
+        kDebug(7116) << "Cyrus IMAP >= 2.3.9 detected, enabling shared seen flag support";
+        imapCapabilities.append( "x-kmail-sharedseen" );
+      }
+    }
+
     kDebug(7116) <<"IMAP4::makeLogin - attempting login";
 
     KIO::AuthInfo authInfo;
@@ -2128,16 +2130,12 @@ bool IMAP4Protocol::makeLogin ()
     }
     else
     {
-#ifdef HAVE_LIBSASL2
       if (!clientAuthenticate (this, authInfo, myHost, myAuth, mySSL, resultInfo))
         error(KIO::ERR_COULD_NOT_AUTHENTICATE, i18n("Unable to authenticate via %1.\n"	"The server %2 replied:\n%3", myAuth, myHost, resultInfo));
       else {
         myUser = authInfo.username;
         myPass = authInfo.password;
       }
-#else
-      error(KIO::ERR_COULD_NOT_LOGIN, i18n("SASL authentication is not compiled into kio_imap4."));
-#endif
     }
     if ( hasCapability("NAMESPACE") )
     {
@@ -2148,7 +2146,6 @@ bool IMAP4Protocol::makeLogin ()
         kDebug(7116) <<"makeLogin - registered namespaces";
       }
       completeQueue.removeAll (cmd);
-      delete cmd;
     }
     // get the default delimiter (empty listing)
     cmd = doCommand( imapCommand::clientList("", "") );
@@ -2168,7 +2165,6 @@ bool IMAP4Protocol::makeLogin ()
       }
     }
     completeQueue.removeAll (cmd);
-    delete cmd;
   } else {
     kDebug(7116) <<"makeLogin - NO login";
   }
@@ -2420,7 +2416,7 @@ IMAP4Protocol::parseURL (const KUrl & _url, QString & _box,
         } else
         {
           // start a listing for the box to get the type
-          imapCommand *cmd;
+          CommandPtr cmd;
 
           cmd = doCommand (imapCommand::clientList ("", _box));
           if (cmd->result () == "OK")
@@ -2595,7 +2591,7 @@ IMAP4Protocol::assureBox (const QString & aBox, bool readonly)
 {
   if (aBox.isEmpty()) return false;
 
-  imapCommand *cmd = 0;
+  CommandPtr cmd;
 
   if (aBox != getCurrentBox () || (!getSelected().readWrite() && !readonly))
   {
