@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2006 Volker Krause <volker.krause@rwth-aachen.de>
+    Copyright (c) 2006 Volker Krause <vkrause@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -31,6 +31,13 @@ class KMimeContentTest : public QObject
     void testImplicitMultipartGeneration();
     void testExplicitMultipartGeneration();
     void testMultipleHeaderExtraction();
+    /**
+      Tests that a message with uuencoded content
+      is parsed correctly and if a corresponding
+      MIME structure is created.
+    */
+    void testParsingUuencoded();
+    void testParent();
 };
 
 #endif
