@@ -58,6 +58,7 @@ class TransportManager::Private
     KConfig *config;
     QList<Transport *> transports;
     bool myOwnChange;
+    bool appliedChange;
     KWallet::Wallet *wallet;
     bool walletOpenFailed;
     bool walletAsyncOpen;
@@ -81,9 +82,10 @@ static void destroyStaticTransportManager() {
 TransportManager::TransportManager()
   : QObject(), d( new Private )
 {
-  KGlobal::locale()->insertCatalog( QLatin1String("libmailtransport") );
+  KGlobal::locale()->insertCatalog( QLatin1String( "libmailtransport" ) );
   qAddPostRoutine( destroyStaticTransportManager );
   d->myOwnChange = false;
+  d->appliedChange = false;
   d->wallet = 0;
   d->walletOpenFailed = false;
   d->walletAsyncOpen = false;
@@ -162,8 +164,9 @@ Transport *TransportManager::createTransport() const
 
 void TransportManager::addTransport( Transport *transport )
 {
-  if ( d->transports.contains( transport ) )
+  if ( d->transports.contains( transport ) ) {
     return;
+  }
 
   d->transports.append( transport );
   validateDefault();
@@ -304,7 +307,7 @@ void TransportManager::readConfig()
 
   QRegExp re( QLatin1String( "^Transport (.+)$" ) );
   QStringList groups = d->config->groupList().filter( re );
-  foreach ( QString s, groups ) {
+  foreach ( const QString &s, groups ) {
     re.indexIn( s );
     Transport *t = 0;
 
@@ -361,14 +364,16 @@ void TransportManager::writeConfig()
 void TransportManager::emitChangesCommitted()
 {
   d->myOwnChange = true; // prevent us from reading our changes again
+  d->appliedChange = false; // but we have to read them at least once
   emit transportsChanged();
   emit changesCommitted();
 }
 
 void TransportManager::slotTransportsChanged()
 {
-  if ( d->myOwnChange ) {
+  if ( d->myOwnChange && d->appliedChange ) {
     d->myOwnChange = false;
+    d->appliedChange = false;
     return;
   }
 
@@ -376,6 +381,7 @@ void TransportManager::slotTransportsChanged()
   d->config->reparseConfiguration();
   // FIXME: this deletes existing transport objects!
   readConfig();
+  d->appliedChange = true; // to prevent recursion
   emit transportsChanged();
 }
 
@@ -543,9 +549,11 @@ void TransportManager::migrateToWallet()
   // ask user if he wants to migrate
   int result = KMessageBox::questionYesNoList(
     0,
-    i18n( "The following mail transports store passwords in the configuration "
-          "file instead in KWallet.\nIt is recommended to use KWallet for "
-          "password storage for security reasons.\n"
+    i18n( "The following mail transports store their passwords in an "
+          "unencrypted configuration file.\nFor security reasons, "
+          "please consider migrating these passwords to KWallet, the "
+          "KDE Wallet management tool,\nwhich stores sensitive data "
+          "for you in a strongly encrypted file.\n"
           "Do you want to migrate your passwords to KWallet?" ),
     names, i18n( "Question" ),
     KGuiItem( i18n( "Migrate" ) ), KGuiItem( i18n( "Keep" ) ),
